summaryrefslogtreecommitdiff
path: root/src/lib/video_decoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-04-07 01:25:12 +0100
committerCarl Hetherington <cth@carlh.net>2013-04-07 01:25:12 +0100
commit21ae33095a251da25b3c5a85bc52fad63e04db0b (patch)
treea67e784269fd9f1f62967cd0f660cf134848bf64 /src/lib/video_decoder.h
parent3cc96e5cc65456f4aeb4625f56087da33da47b48 (diff)
Fix still video playback.
Diffstat (limited to 'src/lib/video_decoder.h')
-rw-r--r--src/lib/video_decoder.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/video_decoder.h b/src/lib/video_decoder.h
index 74343e856..c04874342 100644
--- a/src/lib/video_decoder.h
+++ b/src/lib/video_decoder.h
@@ -30,8 +30,8 @@ class VideoDecoder : public VideoSource, public virtual Decoder
public:
VideoDecoder (boost::shared_ptr<const Film>);
- /** @return video frames per second, or 0 if unknown */
- virtual float frames_per_second () const = 0;
+ /** @return video frame rate second, or 0 if unknown */
+ virtual float video_frame_rate () const = 0;
/** @return native size in pixels */
virtual libdcp::Size native_size () const = 0;
/** @return length according to our content's header */
@@ -59,10 +59,10 @@ protected:
void emit_video (boost::shared_ptr<Image>, double);
void emit_subtitle (boost::shared_ptr<TimedSubtitle>);
bool have_last_video () const;
- void repeat_last_video ();
+ void repeat_last_video (double);
private:
- void signal_video (boost::shared_ptr<Image>, bool, boost::shared_ptr<Subtitle>);
+ void signal_video (boost::shared_ptr<Image>, bool, boost::shared_ptr<Subtitle>, double);
int _video_frame;
double _last_source_time;